//! This module helps to deal with controls.

use crate::engine::input::{Action, Button, Event, Key};

/// The different types of controls.
pub enum Controls {
    /// Default keyboard controls.
    Keyboard,

    /// A gamepad controls the scene.
    Gamepad(u32),
}

impl Controls {
    /// Converts an event into an action if it corresponds to an action.
    pub fn convert(&self, event: Event) -> Option<Action> {
        match self {
            Controls::Keyboard => match event {
                Event::KeyPressed(Key::Space) => Some(Action::ButtonPressed(Button::Button1)),
                Event::KeyReleased(Key::Space) => Some(Action::ButtonReleased(Button::Button1)),
                _ => None,
            },
            Controls::Gamepad(ig) => match event {
                Event::ButtonPressed(ie, button) if *ig == ie => {
                    Some(Action::ButtonPressed(button))
                }
                Event::ButtonReleased(ie, button) if *ig == ie => {
                    Some(Action::ButtonReleased(button))
                }
                _ => None,
            },
        }
    }
}
